@@ -1,4 +1,3 @@
-from six import string_types
 from samtranslator.metrics.method_decorator import cw_timer
 from samtranslator.model import ResourceMacro, PropertyType
 from samtranslator.model.eventsources import FUNCTION_EVETSOURCE_METRIC_PREFIX
@@ -116,6 +115,9 @@ class PullEventSource(ResourceMacro):
 
         destination_config_policy = None
         if self.DestinationConfig:
+            if self.DestinationConfig.get("OnFailure") is None:
+                raise InvalidEventException(self.logical_id, "'OnFailure' is a required field for 'DestinationConfig'")
+
             # `Type` property is for sam to attach the right policies
             destination_type = self.DestinationConfig.get("OnFailure").get("Type")
 
@@ -126,10 +128,6 @@ class PullEventSource(ResourceMacro):
                 # the values 'SQS' and 'SNS' are allowed. No intrinsics are allowed
                 if destination_type not in ["SQS", "SNS"]:
                     raise InvalidEventException(self.logical_id, "The only valid values for 'Type' are 'SQS' and 'SNS'")
-                if self.DestinationConfig.get("OnFailure") is None:
-                    raise InvalidEventException(
-                        self.logical_id, "'OnFailure' is a required field for " "'DestinationConfig'"
-                    )
                 if destination_type == "SQS":
                     queue_arn = self.DestinationConfig.get("OnFailure").get("Destination")
                     destination_config_policy = IAMRolePolicies().sqs_send_message_role_policy(
@@ -140,6 +138,7 @@ class PullEventSource(ResourceMacro):
                     destination_config_policy = IAMRolePolicies().sns_publish_role_policy(
                         sns_topic_arn, self.logical_id
                     )
+
             lambda_eventsourcemapping.DestinationConfig = self.DestinationConfig
 
         if "role" in kwargs:
@@ -189,6 +188,13 @@ class PullEventSource(ResourceMacro):
         if list(self.FilterCriteria.keys()) not in [[], ["Filters"]]:
             raise InvalidEventException(self.relative_id, "FilterCriteria field has a wrong format")
 
+    def validate_secrets_manager_kms_key_id(self):
+        if self.SecretsManagerKmsKeyId and not isinstance(self.SecretsManagerKmsKeyId, str):
+            raise InvalidEventException(
+                self.relative_id,
+                "Provided SecretsManagerKmsKeyId should be of type str.",
+            )
+
 
 class Kinesis(PullEventSource):
     """Kinesis event source."""
@@ -305,6 +311,7 @@ class MQ(PullEventSource):
             },
         }
         if self.SecretsManagerKmsKeyId:
+            self.validate_secrets_manager_kms_key_id()
             kms_policy = {
                 "Action": "kms:Decrypt",
                 "Effect": "Allow",
@@ -368,6 +375,7 @@ class SelfManagedKafka(PullEventSource):
             statements.append(vpc_permissions)
 
         if self.SecretsManagerKmsKeyId:
+            self.validate_secrets_manager_kms_key_id()
             kms_policy = self.get_kms_policy()
             statements.append(kms_policy)
 
@@ -423,7 +431,7 @@ class SelfManagedKafka(PullEventSource):
                 "No {} URI property specified in SourceAccessConfigurations for self managed kafka event.".format(msg),
             )
 
-        if not isinstance(config.get("URI"), string_types) and not is_intrinsic(config.get("URI")):
+        if not isinstance(config.get("URI"), str) and not is_intrinsic(config.get("URI")):
             raise InvalidEventException(
                 self.relative_id,
                 "Wrong Type for {} URI property specified in SourceAccessConfigurations for self managed kafka event.".format(
